@@ -1,7 +1,8 @@
 from typing import Optional, List
 
-from .session import session
+from .session import get_database_session
 from .models import CustomCommand
+from ..util import query_exists
 
 __all__ = (
     'custom_command_exist',
@@ -13,13 +14,14 @@ __all__ = (
 
 
 def custom_command_exist(channel: str, name: str) -> bool:
-    return bool(
-        session.query(CustomCommand).filter(CustomCommand.channel == channel, CustomCommand.name == name).count())
+    session = get_database_session()
+    return query_exists(session, CustomCommand.channel == channel, CustomCommand.name == name)
 
 
 def get_custom_command(channel: str, name: str) -> Optional[CustomCommand]:
     """gets a custom command from the DB, returns the command if found, else None"""
     assert isinstance(name, str), 'name must be of type str'
+    session = get_database_session()
     return session.query(CustomCommand).filter(CustomCommand.channel == channel,
                                                CustomCommand.name == name).one_or_none()
 
@@ -30,6 +32,7 @@ def add_custom_command(cmd: CustomCommand) -> bool:
     if get_custom_command(cmd.channel, cmd.name) is not None:
         return False
 
+    session = get_database_session()
     session.add(cmd)
     session.commit()
     return True
@@ -42,10 +45,11 @@ def delete_custom_command(channel: str, name: str) -> bool:
     if get_custom_command(channel, name) is None:
         return False
 
+    session = get_database_session()
     session.query(CustomCommand).filter(CustomCommand.channel == channel, CustomCommand.name == name).delete()
     session.commit()
     return True
 
 
 def get_all_custom_commands(channel: str) -> List[CustomCommand]:
-    return session.query(CustomCommand).filter(CustomCommand.channel == channel).all()
+    return get_database_session().query(CustomCommand).filter(CustomCommand.channel == channel).all()
